==> zio-aws-robomaker_2.13-5.17.102.8-sources.jar: zio/aws/robomaker/model/SimulationApplicationSummary.scala <==
package zio.aws.robomaker.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import java.time.Instant
import zio.aws.robomaker.model.primitives.{LastUpdatedAt, Version, Arn, Name}
import scala.jdk.CollectionConverters._
final case class SimulationApplicationSummary(
    name: Option[Name] = None,
    arn: Option[Arn] = None,
    version: Option[Version] = None,
    lastUpdatedAt: Option[LastUpdatedAt] = None,
    robotSoftwareSuite: Option[zio.aws.robomaker.model.RobotSoftwareSuite] =
      None,
    simulationSoftwareSuite: Option[
      zio.aws.robomaker.model.SimulationSoftwareSuite
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.robomaker.model.SimulationApplicationSummary = {
    import SimulationApplicationSummary.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.robomaker.model.SimulationApplicationSummary
      .builder()
      .optionallyWith(name.map(value => Name.unwrap(value): java.lang.String))(
        _.name
      )
      .optionallyWith(arn.map(value => Arn.unwrap(value): java.lang.String))(
        _.arn
      )
      .optionallyWith(
        version.map(value => Version.unwrap(value): java.lang.String)
      )(_.version)
      .optionallyWith(
        lastUpdatedAt.map(value => LastUpdatedAt.unwrap(value): Instant)
      )(_.lastUpdatedAt)
      .optionallyWith(robotSoftwareSuite.map(value => value.buildAwsValue()))(
        _.robotSoftwareSuite
      )
      .optionallyWith(
        simulationSoftwareSuite.map(value => value.buildAwsValue())
      )(_.simulationSoftwareSuite)
      .build()
  }
  def asReadOnly
      : zio.aws.robomaker.model.SimulationApplicationSummary.ReadOnly =
    zio.aws.robomaker.model.SimulationApplicationSummary.wrap(buildAwsValue())
}
object SimulationApplicationSummary {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.robomaker.model.SimulationApplicationSummary
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.robomaker.model.SimulationApplicationSummary =
      zio.aws.robomaker.model.SimulationApplicationSummary(
        name.map(value => value),
        arn.map(value => value),
        version.map(value => value),
        lastUpdatedAt.map(value => value),
        robotSoftwareSuite.map(value => value.asEditable),
        simulationSoftwareSuite.map(value => value.asEditable)
      )
    def name: Option[Name]
    def arn: Option[Arn]
    def version: Option[Version]
    def lastUpdatedAt: Option[LastUpdatedAt]
    def robotSoftwareSuite
        : Option[zio.aws.robomaker.model.RobotSoftwareSuite.ReadOnly]
    def simulationSoftwareSuite
        : Option[zio.aws.robomaker.model.SimulationSoftwareSuite.ReadOnly]
    def getName: ZIO[Any, AwsError, Name] =
      AwsError.unwrapOptionField("name", name)
    def getArn: ZIO[Any, AwsError, Arn] = AwsError.unwrapOptionField("arn", arn)
    def getVersion: ZIO[Any, AwsError, Version] =
      AwsError.unwrapOptionField("version", version)
    def getLastUpdatedAt: ZIO[Any, AwsError, LastUpdatedAt] =
      AwsError.unwrapOptionField("lastUpdatedAt", lastUpdatedAt)
    def getRobotSoftwareSuite: ZIO[
      Any,
      AwsError,
      zio.aws.robomaker.model.RobotSoftwareSuite.ReadOnly
    ] = AwsError.unwrapOptionField("robotSoftwareSuite", robotSoftwareSuite)
    def getSimulationSoftwareSuite: ZIO[
      Any,
      AwsError,
      zio.aws.robomaker.model.SimulationSoftwareSuite.ReadOnly
    ] = AwsError.unwrapOptionField(
      "simulationSoftwareSuite",
      simulationSoftwareSuite
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.robomaker.model.SimulationApplicationSummary
  ) extends zio.aws.robomaker.model.SimulationApplicationSummary.ReadOnly {
    override val name: Option[Name] = scala
      .Option(impl.name())
      .map(value => zio.aws.robomaker.model.primitives.Name(value))
    override val arn: Option[Arn] = scala
      .Option(impl.arn())
      .map(value => zio.aws.robomaker.model.primitives.Arn(value))
    override val version: Option[Version] = scala
      .Option(impl.version())
      .map(value => zio.aws.robomaker.model.primitives.Version(value))
    override val lastUpdatedAt: Option[LastUpdatedAt] = scala
      .Option(impl.lastUpdatedAt())
      .map(value => zio.aws.robomaker.model.primitives.LastUpdatedAt(value))
    override val robotSoftwareSuite
        : Option[zio.aws.robomaker.model.RobotSoftwareSuite.ReadOnly] = scala
      .Option(impl.robotSoftwareSuite())
      .map(value => zio.aws.robomaker.model.RobotSoftwareSuite.wrap(value))
    override val simulationSoftwareSuite
        : Option[zio.aws.robomaker.model.SimulationSoftwareSuite.ReadOnly] =
      scala
        .Option(impl.simulationSoftwareSuite())
        .map(value =>
          zio.aws.robomaker.model.SimulationSoftwareSuite.wrap(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.robomaker.model.SimulationApplicationSummary
  ): zio.aws.robomaker.model.SimulationApplicationSummary.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-robomaker_2.13-5.17.176.1-sources.jar: zio/aws/robomaker/model/SimulationApplicationSummary.scala <==
package zio.aws.robomaker.model
import zio.aws.robomaker.model.primitives.{LastUpdatedAt, Version, Arn, Name}
import java.time.Instant
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import scala.jdk.CollectionConverters._
final case class SimulationApplicationSummary(
    name: Optional[Name] = Optional.Absent,
    arn: Optional[Arn] = Optional.Absent,
    version: Optional[Version] = Optional.Absent,
    lastUpdatedAt: Optional[LastUpdatedAt] = Optional.Absent,
    robotSoftwareSuite: Optional[zio.aws.robomaker.model.RobotSoftwareSuite] =
      Optional.Absent,
    simulationSoftwareSuite: Optional[
      zio.aws.robomaker.model.SimulationSoftwareSuite
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.robomaker.model.SimulationApplicationSummary = {
    import SimulationApplicationSummary.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.robomaker.model.SimulationApplicationSummary
      .builder()
      .optionallyWith(name.map(value => Name.unwrap(value): java.lang.String))(
        _.name
      )
      .optionallyWith(arn.map(value => Arn.unwrap(value): java.lang.String))(
        _.arn
      )
      .optionallyWith(
        version.map(value => Version.unwrap(value): java.lang.String)
      )(_.version)
      .optionallyWith(
        lastUpdatedAt.map(value => LastUpdatedAt.unwrap(value): Instant)
      )(_.lastUpdatedAt)
      .optionallyWith(robotSoftwareSuite.map(value => value.buildAwsValue()))(
        _.robotSoftwareSuite
      )
      .optionallyWith(
        simulationSoftwareSuite.map(value => value.buildAwsValue())
      )(_.simulationSoftwareSuite)
      .build()
  }
  def asReadOnly
      : zio.aws.robomaker.model.SimulationApplicationSummary.ReadOnly =
    zio.aws.robomaker.model.SimulationApplicationSummary.wrap(buildAwsValue())
}
object SimulationApplicationSummary {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.robomaker.model.SimulationApplicationSummary
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.robomaker.model.SimulationApplicationSummary =
      zio.aws.robomaker.model.SimulationApplicationSummary(
        name.map(value => value),
        arn.map(value => value),
        version.map(value => value),
        lastUpdatedAt.map(value => value),
        robotSoftwareSuite.map(value => value.asEditable),
        simulationSoftwareSuite.map(value => value.asEditable)
      )
    def name: Optional[Name]
    def arn: Optional[Arn]
    def version: Optional[Version]
    def lastUpdatedAt: Optional[LastUpdatedAt]
    def robotSoftwareSuite
        : Optional[zio.aws.robomaker.model.RobotSoftwareSuite.ReadOnly]
    def simulationSoftwareSuite
        : Optional[zio.aws.robomaker.model.SimulationSoftwareSuite.ReadOnly]
    def getName: ZIO[Any, AwsError, Name] =
      AwsError.unwrapOptionField("name", name)
    def getArn: ZIO[Any, AwsError, Arn] = AwsError.unwrapOptionField("arn", arn)
    def getVersion: ZIO[Any, AwsError, Version] =
      AwsError.unwrapOptionField("version", version)
    def getLastUpdatedAt: ZIO[Any, AwsError, LastUpdatedAt] =
      AwsError.unwrapOptionField("lastUpdatedAt", lastUpdatedAt)
    def getRobotSoftwareSuite: ZIO[
      Any,
      AwsError,
      zio.aws.robomaker.model.RobotSoftwareSuite.ReadOnly
    ] = AwsError.unwrapOptionField("robotSoftwareSuite", robotSoftwareSuite)
    def getSimulationSoftwareSuite: ZIO[
      Any,
      AwsError,
      zio.aws.robomaker.model.SimulationSoftwareSuite.ReadOnly
    ] = AwsError.unwrapOptionField(
      "simulationSoftwareSuite",
      simulationSoftwareSuite
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.robomaker.model.SimulationApplicationSummary
  ) extends zio.aws.robomaker.model.SimulationApplicationSummary.ReadOnly {
    override val name: Optional[Name] = zio.aws.core.internal
      .optionalFromNullable(impl.name())
      .map(value => zio.aws.robomaker.model.primitives.Name(value))
    override val arn: Optional[Arn] = zio.aws.core.internal
      .optionalFromNullable(impl.arn())
      .map(value => zio.aws.robomaker.model.primitives.Arn(value))
    override val version: Optional[Version] = zio.aws.core.internal
      .optionalFromNullable(impl.version())
      .map(value => zio.aws.robomaker.model.primitives.Version(value))
    override val lastUpdatedAt: Optional[LastUpdatedAt] = zio.aws.core.internal
      .optionalFromNullable(impl.lastUpdatedAt())
      .map(value => zio.aws.robomaker.model.primitives.LastUpdatedAt(value))
    override val robotSoftwareSuite
        : Optional[zio.aws.robomaker.model.RobotSoftwareSuite.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.robotSoftwareSuite())
        .map(value => zio.aws.robomaker.model.RobotSoftwareSuite.wrap(value))
    override val simulationSoftwareSuite
        : Optional[zio.aws.robomaker.model.SimulationSoftwareSuite.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.simulationSoftwareSuite())
        .map(value =>
          zio.aws.robomaker.model.SimulationSoftwareSuite.wrap(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.robomaker.model.SimulationApplicationSummary
  ): zio.aws.robomaker.model.SimulationApplicationSummary.ReadOnly =
    new Wrapper(impl)
}
